<table>
  <tr>
    <td class="celda-i" style="width: {{ ancho1 }};">
      <label>{{ label1 }}</label>
      <input type="text" value="{{ valor1 }}">
    </td>
    <td class="celda-d" style="width: {{ ancho2 }};">
      <label>{{ label2 }}</label>
      <input type="text" value="{{ valor2 }}">
    </td>
  </tr>
</table>
