<div class="columna" style="padding-top: 0px; margin-bottom: 8px;">
    <p style=" font-size: 11px; color: #002857; font-weight: 500; text-align: justify; margin: 0px 20px 0px 20px">
        * En caso de respuesta afirmativa, la UNP informa que durante el desarrollo de la actuación adelantada
        por la Entidad podrá solicitar revocar esta autorización y solicitar por escrito que las notificaciones
        o comunicaciones sucesivas se realicen a través de otros medios previstos en la Ley 1437 de 2011 -
        CPACA.
    </p>
</div>