<div style="width: 100%; margin: 40px 0; text-align: center;">
    <div style="width: 300px; margin: 0 auto 20px auto; border-bottom: 2px solid #002857; min-height: 40px;"></div>
    <div>
        <strong>{{ nombre_firma }}</strong>
        <br>
        <span style="font-size: 15px; color: #002857; font-weight: 500;">
            {{ cargo_firma }}
        </span>
    </div>
</div>