<table>
  <tr>
    <th>FECHA (DD-MM-AA)</th>
    <th>CORREO ELECTRÓNICO</th>
    <th>OBSERVACIONES</th>
  </tr>
  {% for fila in filas %}
  <tr>
    <td style="text-align: center;">{{ fila.fecha }}</td>
    <td style="text-align: center;">{{ fila.correo }}</td>
    <td style="text-align: center;">{{ fila.observaciones }}</td>
  </tr>
  {% endfor %}
</table>
